@@ -1,24 +1,17 @@
-from __future__ import unicode_literals
-
 import hashlib
 from importlib import import_module
 
-from django import VERSION
 from django.conf import settings
 from django.core.exceptions import ValidationError
-if VERSION < (1, 10):
-    from django.core.urlresolvers import reverse
-else:
-    from django.urls import reverse
 from django.db import models
 from django.db.models import IntegerField, Value
 from django.db.models.expressions import RawSQL
 from django.db.models.query import QuerySet
-from django.utils import six
-from django.utils.encoding import force_text, python_2_unicode_compatible
+from django.urls import reverse
+from django.utils.encoding import force_str
 from django.utils.text import Truncator
 from django.utils.timezone import now
-from django.utils.translation import ugettext, ugettext_lazy as _
+from django.utils.translation import gettext, gettext_lazy as _
 if getattr(settings, 'POSTMAN_I18N_URLS', False):
     from django.utils.translation import pgettext_lazy
 else:
@@ -50,8 +43,7 @@ ORDER_BY_MAPPER = {'sender': 'f', 'recipient': 't', 'subject': 's', 'date': 'd'}
 def setup():
     """
     Deferred actions, that can not be done at import time since Django 1.7.
-    Normally called in AppConfig.ready().
-    For backwards compatibility, also called on first need.
+    Called in AppConfig.ready().
 
     """
     from django.contrib.auth import get_user_model
@@ -74,8 +66,6 @@ def get_order_by(query_dict):
     """
     if ORDER_BY_KEY in query_dict:
         code = query_dict[ORDER_BY_KEY]  # code may be uppercase or lowercase
-        if not ORDER_BY_FIELDS:  # backwards compatibility, before Django 1.7
-            setup()
         order_by_field = ORDER_BY_FIELDS.get(code.lower())
         if order_by_field:
             if code.isupper():
@@ -88,11 +78,11 @@ def get_user_representation(user):
     Return a User representation for display, configurable through an optional setting.
     """
     show_user_as = getattr(settings, 'POSTMAN_SHOW_USER_AS', None)
-    if isinstance(show_user_as, six.string_types):
+    if isinstance(show_user_as, str):
         if '.' in show_user_as:
             mod_path, _, attr_name = show_user_as.rpartition('.')
             try:
-                return force_text(getattr(import_module(mod_path), attr_name)(user))
+                return force_str(getattr(import_module(mod_path), attr_name)(user))
             except:  # ImportError, AttributeError, TypeError (not callable)
                 pass
         else:
@@ -100,13 +90,13 @@ def get_user_representation(user):
             if callable(attr):
                 attr = attr()
             if attr:
-                return force_text(attr)
+                return force_str(attr)
     elif callable(show_user_as):
         try:
-            return force_text(show_user_as(user))
+            return force_str(show_user_as(user))
         except:
             pass
-    return force_text(user)  # default value, or in case of empty attribute or exception
+    return force_str(user)  # default value, or in case of empty attribute or exception
 
 
 def get_user_name(user):
@@ -115,7 +105,7 @@ def get_user_name(user):
     """
     name_user_as = getattr(settings, 'POSTMAN_NAME_USER_AS', None)
     if name_user_as:
-        return force_text(getattr(user, name_user_as))
+        return force_str(getattr(user, name_user_as))
     return user.get_username()  # default
 
 
@@ -260,7 +250,6 @@ class MessageManager(models.Manager):
         ).update(read_at=now())
 
 
-@python_2_unicode_compatible
 class Message(models.Model):
     """
     A message between a User and another User or an AnonymousUser.
@@ -410,7 +399,7 @@ class Message(models.Model):
     def clean(self):
         """Check some validity constraints."""
         if not (self.sender_id is not None or self.email):
-            raise ValidationError(ugettext("Undefined sender."))
+            raise ValidationError(gettext("Undefined sender."))
 
     def clean_moderation(self, initial_status, user=None):
         """Adjust automatically some fields, according to status workflow."""
@@ -542,12 +531,9 @@ class Message(models.Model):
 class PendingMessageManager(models.Manager):
     """The manager for PendingMessage."""
 
-    def get_query_set(self):  # for Django <= 1.5
-        return super(PendingMessageManager, self).get_query_set().filter(moderation_status=STATUS_PENDING)
-
-    def get_queryset(self):  # changed in Django 1.6: "The get_queryset method was previously named get_query_set."
+    def get_queryset(self):
         """Filter to get only pending objects."""
-        return super(PendingMessageManager, self).get_queryset().filter(moderation_status=STATUS_PENDING)
+        return super().get_queryset().filter(moderation_status=STATUS_PENDING)
 
 
 class PendingMessage(Message):
