@@ -2,8 +2,9 @@
 Utilities for tests.py usage.
 
 """
-from __future__ import unicode_literals
 
+from django.conf import settings
+from django.core.mail import send_mail
 
 class UserRepresentation:
     "POSTMAN_SHOW_USER_AS = 'postman.module_for_tests.UserRepresentation'"
@@ -21,3 +22,8 @@ def user_representation(user):
 
 def notification_approval(user, action, site):
     return '{}_{}@domain.tld'.format(user.username, action)  # a way to prove at the same time the parameters transmission
+
+
+def send(users, label, extra_context):
+    "POSTMAN_NOTIFIER_APP = 'postman.module_for_tests'"
+    send_mail('subject', 'message', settings.DEFAULT_FROM_EMAIL, [users[0].email])
\ No newline at end of file
