@@ -1,23 +1,18 @@
-from __future__ import unicode_literals
+from urllib.parse import urlsplit, urlunsplit
 
-from django import VERSION
 from django.conf import settings
 from django.contrib import messages
 from django.contrib.auth.decorators import login_required
 from django.contrib.auth import get_user_model
 from django.contrib.sites.shortcuts import get_current_site
-if VERSION < (1, 10):
-    from django.core.urlresolvers import reverse
-else:
-    from django.urls import reverse
 from django.db.models import Q
 from django.http import Http404
 from django.shortcuts import get_object_or_404, redirect
+from django.urls import reverse
 from django.utils.decorators import method_decorator
-from django.utils.encoding import force_text
-from django.utils.six.moves.urllib.parse import urlsplit, urlunsplit  # Django 1.4.11, 1.5.5
+from django.utils.encoding import force_str
 from django.utils.timezone import now
-from django.utils.translation import ugettext as _, ugettext_lazy
+from django.utils.translation import gettext as _, gettext_lazy
 from django.views.decorators.cache import never_cache
 from django.views.decorators.csrf import csrf_protect
 from django.views.decorators.debug import sensitive_post_parameters
@@ -74,7 +69,7 @@ class NamespaceMixin(object):
 
     def render_to_response(self, context, **response_kwargs):
         self.request.current_app = self.request.resolver_match.namespace
-        return super(NamespaceMixin, self).render_to_response(context, **response_kwargs)
+        return super().render_to_response(context, **response_kwargs)
 
 
 class FolderMixin(NamespaceMixin, object):
@@ -84,10 +79,10 @@ class FolderMixin(NamespaceMixin, object):
     @never_cache_m
     @login_required_m
     def dispatch(self, *args, **kwargs):
-        return super(FolderMixin, self).dispatch(*args, **kwargs)
+        return super().dispatch(*args, **kwargs)
 
     def get_context_data(self, **kwargs):
-        context = super(FolderMixin, self).get_context_data(**kwargs)
+        context = super().get_context_data(**kwargs)
         params = {}
         option = kwargs.get('option')
         if option:
@@ -191,7 +186,7 @@ class ComposeMixin(NamespaceMixin, object):
     auto_moderators = []
 
     def get_form_kwargs(self):
-        kwargs = super(ComposeMixin, self).get_form_kwargs()
+        kwargs = super().get_form_kwargs()
         if self.request.method == 'POST':
             kwargs.update({
                 'sender': self.request.user,
@@ -217,7 +212,7 @@ class ComposeMixin(NamespaceMixin, object):
         return redirect(self.get_success_url())
 
     def get_context_data(self, **kwargs):
-        context = super(ComposeMixin, self).get_context_data(**kwargs)
+        context = super().get_context_data(**kwargs)
         context.update({
             'autocompleter_app': autocompleter_app,
             'next_url': self.request.GET.get('next') or _get_referer(self.request),
@@ -247,15 +242,14 @@ class WriteView(ComposeMixin, FormView):
     @csrf_protect_m
     def dispatch(self, *args, **kwargs):
         if getattr(settings, 'POSTMAN_DISALLOW_ANONYMOUS', False):
-            return login_required(super(WriteView, self).dispatch)(*args, **kwargs)
-        return super(WriteView, self).dispatch(*args, **kwargs)
+            return login_required(super().dispatch)(*args, **kwargs)
+        return super().dispatch(*args, **kwargs)
 
     def get_form_class(self):
-        is_authenticated = self.request.user.is_authenticated if VERSION >= (1, 10) else self.request.user.is_authenticated()
-        return self.form_classes[0 if is_authenticated else 1]
+        return self.form_classes[0 if self.request.user.is_authenticated else 1]
 
     def get_initial(self):
-        initial = super(WriteView, self).get_initial()
+        initial = super().get_initial()
         if self.request.method == 'GET':
             initial.update(self.request.GET.items())  # allow optional initializations by query string
             recipients = self.kwargs.get('recipients')
@@ -269,14 +263,13 @@ class WriteView(ComposeMixin, FormView):
                     **{'{0}__in'.format(name_user_as): [r.strip() for r in recipients.split(':') if r and not r.isspace()]}
                 ).order_by(name_user_as))
                 if usernames:
-                    initial['recipients'] = ', '.join(map(force_text, usernames))
+                    initial['recipients'] = ', '.join(map(force_str, usernames))
         return initial
 
     def get_form_kwargs(self):
-        kwargs = super(WriteView, self).get_form_kwargs()
+        kwargs = super().get_form_kwargs()
         if isinstance(self.autocomplete_channels, tuple) and len(self.autocomplete_channels) == 2:
-            is_anonymous = self.request.user.is_anonymous if VERSION >= (1, 10) else self.request.user.is_anonymous()
-            channel = self.autocomplete_channels[1 if is_anonymous else 0]
+            channel = self.autocomplete_channels[1 if self.request.user.is_anonymous else 0]
         else:
             channel = self.autocomplete_channels
         kwargs['channel'] = channel
@@ -307,7 +300,7 @@ class ReplyView(ComposeMixin, FormView):
     def dispatch(self, request, message_id, *args, **kwargs):
         perms = Message.objects.perms(request.user)
         self.parent = get_object_or_404(Message, perms, pk=message_id)
-        return super(ReplyView, self).dispatch(request, *args, **kwargs)
+        return super().dispatch(request, *args, **kwargs)
 
     def get_initial(self):
         self.initial = self.parent.quote(*self.formatters)  # will also be partially used in get_form_kwargs()
@@ -316,7 +309,7 @@ class ReplyView(ComposeMixin, FormView):
         return self.initial
 
     def get_form_kwargs(self):
-        kwargs = super(ReplyView, self).get_form_kwargs()
+        kwargs = super().get_form_kwargs()
         kwargs['channel'] = self.autocomplete_channel
         if self.request.method == 'POST':
             if 'subject' not in kwargs['data']:  # case of the quick reply form
@@ -327,7 +320,7 @@ class ReplyView(ComposeMixin, FormView):
         return kwargs
 
     def get_context_data(self, **kwargs):
-        context = super(ReplyView, self).get_context_data(**kwargs)
+        context = super().get_context_data(**kwargs)
         context['recipient'] = self.parent.obfuscated_sender
         return context
 
@@ -350,7 +343,7 @@ class DisplayMixin(NamespaceMixin, object):
     @never_cache_m
     @login_required_m
     def dispatch(self, *args, **kwargs):
-        return super(DisplayMixin, self).dispatch(*args, **kwargs)
+        return super().dispatch(*args, **kwargs)
 
     def get(self, request, *args, **kwargs):
         user = request.user
@@ -361,10 +354,10 @@ class DisplayMixin(NamespaceMixin, object):
             if m.recipient == user and m.is_accepted() and m.read_at is None:
                 Message.objects.set_read(user, self.filter)
                 break
-        return super(DisplayMixin, self).get(request, *args, **kwargs)
+        return super().get(request, *args, **kwargs)
 
     def get_context_data(self, **kwargs):
-        context = super(DisplayMixin, self).get_context_data(**kwargs)
+        context = super().get_context_data(**kwargs)
         user = self.request.user
         # are all messages archived ?
         for m in self.msgs:
@@ -395,7 +388,7 @@ class MessageView(DisplayMixin, TemplateView):
 
     def get(self, request, message_id, *args, **kwargs):
         self.filter = Q(pk=message_id)
-        return super(MessageView, self).get(request, *args, **kwargs)
+        return super().get(request, *args, **kwargs)
 
 
 class ConversationView(DisplayMixin, TemplateView):
@@ -403,7 +396,7 @@ class ConversationView(DisplayMixin, TemplateView):
 
     def get(self, request, thread_id, *args, **kwargs):
         self.filter = Q(thread=thread_id)
-        return super(ConversationView, self).get(request, *args, **kwargs)
+        return super().get(request, *args, **kwargs)
 
 
 class UpdateMessageMixin(object):
@@ -425,7 +418,7 @@ class UpdateMessageMixin(object):
     @csrf_protect_m
     @login_required_m
     def dispatch(self, *args, **kwargs):
-        return super(UpdateMessageMixin, self).dispatch(*args, **kwargs)
+        return super().dispatch(*args, **kwargs)
 
     def post(self, request, *args, **kwargs):
         next_url = _get_referer(request) or 'postman:inbox'
@@ -459,21 +452,21 @@ class UpdateDualMixin(UpdateMessageMixin):
 class ArchiveView(UpdateDualMixin, View):
     """Mark messages/conversations as archived."""
     field_bit = 'archived'
-    success_msg = ugettext_lazy("Messages or conversations successfully archived.")
+    success_msg = gettext_lazy("Messages or conversations successfully archived.")
     field_value = True
 
 
 class DeleteView(UpdateDualMixin, View):
     """Mark messages/conversations as deleted."""
     field_bit = 'deleted_at'
-    success_msg = ugettext_lazy("Messages or conversations successfully deleted.")
+    success_msg = gettext_lazy("Messages or conversations successfully deleted.")
     field_value = now()
 
 
 class UndeleteView(UpdateDualMixin, View):
     """Revert messages/conversations from marked as deleted."""
     field_bit = 'deleted_at'
-    success_msg = ugettext_lazy("Messages or conversations successfully recovered.")
+    success_msg = gettext_lazy("Messages or conversations successfully recovered.")
 
 
 class UpdateRecipientMixin(UpdateMessageMixin):
@@ -487,11 +480,11 @@ class UpdateRecipientMixin(UpdateMessageMixin):
 class MarkReadView(UpdateRecipientMixin, View):
     """Mark messages/conversations as read."""
     field_bit = 'read_at'
-    success_msg = ugettext_lazy("Messages or conversations successfully marked as read.")
+    success_msg = gettext_lazy("Messages or conversations successfully marked as read.")
     field_value = now()
 
 
 class MarkUnreadView(UpdateRecipientMixin, View):
     """Revert messages/conversations from marked as read."""
     field_bit = 'read_at'
-    success_msg = ugettext_lazy("Messages or conversations successfully marked as unread.")
+    success_msg = gettext_lazy("Messages or conversations successfully marked as unread.")
